DSFeatureFlagProvider class abstract

Abstract base class for feature flag providers in DartStream. Ensures a consistent interface across all providers.

Constructors

DSFeatureFlagProvider()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

evaluateFlag(String flagKey, {Map<String, dynamic>? context}) Future<DSFeatureFlagEvaluationResult>
Evaluates a feature flag and returns detailed results.
getBooleanFlag(String flagKey, {bool defaultValue = false, Map<String, dynamic>? context}) Future<bool>
Fetches the value of a feature flag as a boolean.
getJsonFlag(String flagKey, {Map<String, dynamic> defaultValue = const {}, Map<String, dynamic>? context}) Future<Map<String, dynamic>>
Fetches the value of a feature flag as JSON.
getNumberFlag(String flagKey, {num defaultValue = 0, Map<String, dynamic>? context}) Future<num>
Fetches the value of a feature flag as a number.
getStringFlag(String flagKey, {String defaultValue = '', Map<String, dynamic>? context}) Future<String>
Fetches the value of a feature flag as a string.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited