DSFeatureFlagEvaluationResult class
Represents the result of a feature flag evaluation.
Constructors
- DSFeatureFlagEvaluationResult({required dynamic value, required String reason, String variant = ''})
- Constructor for creating an evaluation result.
-
DSFeatureFlagEvaluationResult.fromJson(Map<
String, dynamic> json) -
Factory constructor to create a result from JSON.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- reason → String
-
The reason for the flag's state (e.g., "default", "targeting_match").
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → dynamic
-
The value of the evaluated feature flag.
final
- variant → String
-
The variant of the flag (if applicable).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts the evaluation result to a JSON-compatible map.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited